#!/usr/bin/python
# vim: tabstop=2 expandtab autoindent

import string, sys, getopt
from pyPgSQL import PgSQL

connection = PgSQL.connect(database='mjt_cd_database', user='mjt')
connection.autocommit = 1
cursor = connection.cursor()

def usage():
  print 'USAGE: %s [OPTIONS]' % sys.argv[0]
  print
  print '-a, --artist=[ARTIST]      Artist whose CD to add, case insensitive'
  print '-d, --disc=[DISC]          Name of CD to add'
  print '-y, --year=[YEAR]          Optional release year, must be a number'
  print '-n, --num=[NUMBER]         Number of discs, defaults to 1'
  print '    --id=[ID]              Numeric ID of artist whose CD to add'
  print '    --ltd                  The disc is a limited edition'
  print
  print '    --list-artists         List Artists'

  connection.close()
  sys.exit(1)

def list_artists():
  qry = 'SELECT name, id \
  FROM artist \
  ORDER BY name'
  cursor.execute(qry)
  res = cursor.fetchall()
  connection.close()

  lenname = 0
  for artname, artid in res:
    if len(str(artname)) > lenname:
      lenname = len(str(artname))

  res.insert(0, ['Name', 'ID'])
  output = []
  lenrow = 0
  for artname, artid in res:
    pad = lenname-len(artname) + 2
    row = '%s %' + str(pad) + 's'
    row = row % (artname, artid)
    output.append(row)
    if len(row) > lenrow:
      lenrow = len(row)

  output.insert(1, lenrow*'=')
  for o in output:
    print o

  sys.exit(0)
    

if len(sys.argv) == 1:
  usage()

# MAIN STUFF
opts, args = getopt.getopt(sys.argv[1:],
                          'a:d:n:y:',
                          ['artist=', 'disc=', 'id=', 'num=', 'year=',
                          'list-artists', 'ltd'])

artistid = None
artist = None
disc = None
year = 0
num = 1
is_ltd = 0
for opt, arg in opts:
  if opt == '--list-artists':
    list_artists()
  elif opt == '--id':
    artistid = arg
  elif opt in ['-a', '--artist'] and not artistid:
    artist = arg
  elif opt in ['-d', '--disc']:
    disc = arg
  elif opt in ['-y', '--year']:
    year = arg
  elif opt in ['-n', '--num']:
    num = arg
  elif opt == '--ltd':
    is_ltd = 1

# We have insufficient parameters and want to die
if not disc or not (artist or artistid):
  usage()

# Get an artist id if the name was supplied

if artist and not artistid:
  qry = 'SELECT id \
        FROM artist \
        WHERE Upper(name)=Upper(\'%s\')' % artist

  cursor.execute(qry)
  res = cursor.fetchone()
  if not res:
    print 'Unknown artist: %s' % artist
    connection.close()
    sys.exit(1)
  else:
    artistid = res[0]

# Check if the artist has a disc like that
qry = 'SELECT a.name, d.name, d.release_year \
      FROM artist a, disc d \
      WHERE d.artistid=a.id \
      AND Upper(d.name)=Upper(\'%s\') \
      AND a.id=%s' % (disc, artistid)

cursor.execute(qry)
res = cursor.fetchone()
if res:
  print '%s already exists:' % disc
  print '%s: %s (%s)' % tuple(res)
  connection.close()
  sys.exit(1)

# Update the table
qry = 'INSERT INTO disc \
      (name, artistid, num, release_year, is_ltd) \
      VALUES (\'%s\', \'%s\', \'%s\', \'%s\', \'%s\')' % (disc, artistid, num, year, is_ltd)

cursor.execute(qry)

# Maybe a -q switch could quiet this down? It's an unnecessary query
# if we don't want the disc ID...
qry = 'SELECT id, name, release_year, num\
      FROM disc \
      WHERE Upper(name)=Upper(\'%s\') \
      AND disc.artistid=%s' % (disc, artistid)

cursor.execute(qry)
res = cursor.fetchone()
print 'ID: %s' % res[0]
print 'Name: %s' % res[1]
print 'Year: %s' % res[2]
print 'Num: %s' % res[3]
print 'Added'

